@@ -17,10 +17,10 @@
 
 #define H2CORE_VERSION_MAJOR 1
 #define H2CORE_VERSION_MINOR 2
-#define H2CORE_VERSION_PATCH 4
+#define H2CORE_VERSION_PATCH 6
 
 #define H2CORE_GIT_REVISION 
-#define H2CORE_VERSION "1.2.4-"
+#define H2CORE_VERSION "1.2.6-"
 #define H2CORE_IS_DEVEL_BUILD true
 
 
@@ -38,6 +38,9 @@
 #ifndef H2CORE_HAVE_DEBUG
 /* #undef H2CORE_HAVE_DEBUG */
 #endif
+#ifndef H2CORE_HAVE_QT6
+/* #undef H2CORE_HAVE_QT6 */
+#endif
 #ifndef H2CORE_HAVE_BUNDLE
 /* #undef H2CORE_HAVE_BUNDLE */
 #endif
